@@ -111,7 +111,6 @@ def get_news():
         print(html[a],end="")
         a+=1
     print("\033[0m")
-
 def get_imformation(pid):
     try:
         url="http://code.xueersi.com/api/compilers/"+str(pid)+"?id="+str(pid)
@@ -123,4 +122,12 @@ def get_imformation(pid):
         unlikes=p["data"]["unlikes"]
         return likes,unlikes,p["data"]["username"],p["data"]["user_id"]
     except:
-        return -1
\ No newline at end of file
+        return -1
+def printf(text):
+    text=str(text)
+    for i in text:
+        print(i,end='')
+        time.sleep(0.1)
+def cleardevice():
+    print("\033[2J")
+    print("\033[99999999999999999999999999999999A", end='')
\ No newline at end of file
